@@ -1,11 +1,11 @@
 package MacOSX::File;
 
-use 5.6.0;
+use 5.006;
 use strict;
 use Carp;
 
-our $RCSID = q$Id: File.pm,v 0.68 2004/05/25 16:01:50 dankogai Exp $;
-our $VERSION = do { my @r = (q$Revision: 0.68 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $RCSID = q$Id: File.pm,v 0.69 2004/08/05 03:18:15 dankogai Exp dankogai $;
+our $VERSION = do { my @r = (q$Revision: 0.69 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 require Exporter;
 require DynaLoader;
